==> haskell-newtype-generics-0.5.3-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-GWdkBLw8hs31J4EzWBTwGn
key: newtype-generics-0.5.3-GWdkBLw8hs31J4EzWBTwGn
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 3557cc7e18c7773efc2a59288422f5ae
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-GWdkBLw8hs31J4EzWBTwGn
depends:
    base-4.12.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-generics-0.5.3-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-AV43oaXa2XzIqNO5fCKrpE
key: newtype-generics-0.5.3-AV43oaXa2XzIqNO5fCKrpE
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 57a7b19ea3786b7bace99594b988dc0e
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-AV43oaXa2XzIqNO5fCKrpE
depends:
    base-4.12.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
